@@ -1,21 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# pycoast, Writing of coastlines, borders and rivers to images in Python
-#
-# Copyright (C) 2011-2020 PyCoast Developers
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """ContourWriter based on the aggdraw library."""
 
 import logging
@@ -133,8 +115,8 @@ class ContourWriterAGG(ContourWriterBase):
         outline_opacity = kwargs.get("outline_opacity", 255)
 
         # draw '|'
-        (x_bm, y_bm) = (x, y - half_ptsize)  # bottom middle point
-        (x_tm, y_tm) = (x, y + half_ptsize)  # top middle point
+        x_bm, y_bm = (x, y - half_ptsize)  # bottom middle point
+        x_tm, y_tm = (x, y + half_ptsize)  # top middle point
         self._draw_line(
             draw,
             [x_bm, y_bm, x_tm, y_tm],
@@ -143,8 +125,8 @@ class ContourWriterAGG(ContourWriterBase):
             outline_opacity=outline_opacity,
         )
         # draw '-'
-        (x_lm, y_lm) = (x - half_ptsize, y)  # left middle point
-        (x_rm, y_rm) = (x + half_ptsize, y)  # right middle point
+        x_lm, y_lm = (x - half_ptsize, y)  # left middle point
+        x_rm, y_rm = (x + half_ptsize, y)  # right middle point
         self._draw_line(
             draw,
             [x_lm, y_lm, x_rm, y_rm],
@@ -153,8 +135,8 @@ class ContourWriterAGG(ContourWriterBase):
             outline_opacity=outline_opacity,
         )
         # draw '/'
-        (x_bl, y_bl) = (x - half_ptsize, y - half_ptsize)  # bottom left point
-        (x_tr, y_tr) = (x + half_ptsize, y + half_ptsize)  # top right point
+        x_bl, y_bl = (x - half_ptsize, y - half_ptsize)  # bottom left point
+        x_tr, y_tr = (x + half_ptsize, y + half_ptsize)  # top right point
         self._draw_line(
             draw,
             [x_bl, y_bl, x_tr, y_tr],
@@ -163,8 +145,8 @@ class ContourWriterAGG(ContourWriterBase):
             outline_opacity=outline_opacity,
         )
         # draw '\'
-        (x_tl, y_tl) = (x - half_ptsize, y + half_ptsize)  # top left point
-        (x_br, y_br) = (x + half_ptsize, y - half_ptsize)  # bottom right point
+        x_tl, y_tl = (x - half_ptsize, y + half_ptsize)  # top left point
+        x_br, y_br = (x + half_ptsize, y - half_ptsize)  # bottom right point
         self._draw_line(
             draw,
             [x_tl, y_tl, x_br, y_br],
