@@ -1,21 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-# pycoast, Writing of coastlines, borders and rivers to images in Python
-#
-# Copyright (C) 2011-2020 PyCoast Developers
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Main unit tests for pycoast."""
 
 import os
@@ -2121,4 +2103,4 @@ def _create_background_image(add_pattern: bool, background_mode: str) -> Image:
     if add_pattern:
         img_data[6:30, 6:30, 0] = 127
         img_data[6:30, -30:-6, 0] = 127
-    return Image.fromarray(img_data, mode=background_mode)
+    return Image.fromarray(img_data)
